@@ -55,7 +55,7 @@ utils::globalVariables(c("silentText","silentGraph","silentLegend","initialType"
 #'
 #' @export auto.ces
 auto.ces <- function(y, models=c("none","simple","full"),
-                initial=c("optimal","backcasting"), ic=c("AICc","AIC","BIC","BICc"),
+                initial=c("backcasting","optimal"), ic=c("AICc","AIC","BIC","BICc"),
                 loss=c("MSE","MAE","HAM","MSEh","TMSE","GTMSE","MSCE"),
                 h=10, holdout=FALSE, cumulative=FALSE,
                 interval=c("none","parametric","semiparametric","nonparametric"), level=0.95,
