@@ -90,6 +90,13 @@ vssInput <- function(smoothType=c("ves"),...){
     # Number of series in the matrix
     nSeries <- ncol(y);
 
+    correlatedSeries <- cor(y)[upper.tri(cor(y))];
+    if(any(correlatedSeries>0.999)){
+        warning(paste0("Some of series are almost perfectly correlated. This might cause difficulties in the estimation. ",
+                       "Please, try removing some of them if you encounter any problems."),
+                call.=FALSE);
+    }
+
     if(is.null(ncol(y))){
         stop("The provided data is not a matrix! Use es() function instead!", call.=FALSE);
     }
@@ -306,8 +313,8 @@ vssInput <- function(smoothType=c("ves"),...){
         modelIsMultiplicative <- FALSE;
     }
 
-    #This is the estimation of covariance matrix
-    nParamMax <- 1;
+    # This is the number of parameters to estimate per series
+    nParamMax <- 0;
 
     ##### Persistence matrix ####
     # persistence type can be: "i" - individual, "d" - dependent, "c" - common (all),
@@ -391,11 +398,19 @@ vssInput <- function(smoothType=c("ves"),...){
         }
     }
 
-    if(any(persistenceType==c("c","i","s"))){
-        # Whether individual, seasonal or group, this thing reduces number of
-        # degrees of freedom in the same way.
+    # If it is individual, then it increases by nComponentsAll
+    if(persistenceType=="i"){
+    # if(any(persistenceType==c("c","i","s"))){
         nParamMax <- nParamMax + nComponentsAll;
     }
+    # The seasonal is shared across series, the other parameters are individual
+    else if(persistenceType=="s"){
+        nParamMax <- nParamMax + nComponentsNonSeasonal + 1/nSeries;
+    }
+    # All parameters are shared
+    else if(persistenceType=="c"){
+        nParamMax <- nParamMax + nComponentsAll/nSeries;
+    }
     else if(persistenceType=="d"){
         # In case with "dependent" the whole matrix needs to be estimated
         nParamMax <- nParamMax + nComponentsAll*nSeries;
@@ -568,8 +583,13 @@ vssInput <- function(smoothType=c("ves"),...){
 
             if(any(dampedType==c("c","i"))){
                 dampedValue <- matrix(1,nSeries,1);
-                # Whether group or individual the effect on df is the same.
-                nParamMax <- nParamMax + 1;
+                # In case of common, the parameter is shared.
+                if(dampedType=="c"){
+                    nParamMax <- nParamMax + 1/nSeries;
+                }
+                else{
+                    nParamMax <- nParamMax + 1;
+                }
             }
         }
         else{
@@ -643,9 +663,14 @@ vssInput <- function(smoothType=c("ves"),...){
         }
     }
 
-    if(any(initialType==c("c","i"))){
+    # Individual initials
+    if(initialType=="i"){
         nParamMax <- nParamMax + nComponentsNonSeasonal;
     }
+    # Common initials are shared across series
+    else{
+        nParamMax <- nParamMax + nComponentsNonSeasonal / nSeries;
+    }
 
     if(smoothType=="ves"){
     ##### initialSeason and seasonal for VES #####
@@ -766,9 +791,12 @@ vssInput <- function(smoothType=c("ves"),...){
                 }
             }
 
-            if(any(initialSeasonType==c("c","i"))){
+            if(initialSeasonType=="i"){
                 nParamMax <- nParamMax + dataFreq;
             }
+            else if(initialSeasonType=="c"){
+                nParamMax <- nParamMax + dataFreq / nSeries;
+            }
         }
         else{
             initialSeasonValue <- NULL;
@@ -786,6 +814,15 @@ vssInput <- function(smoothType=c("ves"),...){
     }
     loss <- substr(loss,1,1);
 
+    # If it is likelihood, we also need to estimate the full covariance matrix
+    if(loss=="l"){
+        nParamMax <- nParamMax + nSeries;
+    }
+    # Otherwise, these are just variances of the data
+    else{
+        nParamMax <- nParamMax + 1;
+    }
+
     normalizer <- sum(colMeans(abs(diff(t(yInSample))),na.rm=TRUE));
 
     ##### Information Criteria #####
@@ -846,7 +883,7 @@ vssInput <- function(smoothType=c("ves"),...){
 
     ##### Check number of observations vs number of max parameters #####
     if(obsInSample <= nParamMax){
-        stop(paste0("Not enough observations for the reasonable fit. Number of parameters is ",
+        stop(paste0("Not enough observations for the reasonable fit. Number of parameters per series is ",
                     nParamMax," while the number of observations is ",obsInSample,"."),call.=FALSE);
     }
 
